@@ -4,11 +4,15 @@
 -- | This module extends "Data.Either" with extra operations, particularly
 --   to quickly extract from inside an 'Either'. Some of these operations are
 --   partial, and should be used with care in production-quality code.
+--
+--   If you need more 'Either' functions see the
+--   <https://hackage.haskell.org/package/either either>.
 module Data.Either.Extra(
     module Data.Either,
-    isLeft, isRight, fromLeft, fromRight, fromEither,
+    fromLeft, fromRight, fromEither,
     fromLeft', fromRight',
     eitherToMaybe, maybeToEither,
+    mapLeft, mapRight,
     ) where
 
 import Data.Either
@@ -57,18 +61,6 @@ fromRight' (Right x) = x
 fromRight' _ = error "fromRight', given a Left"
 
 
-#if __GLASGOW_HASKELL__ < 708
--- | Test if an 'Either' value is the 'Left' constructor.
---   Provided as standard with GHC 7.8 and above.
-isLeft :: Either l r -> Bool
-isLeft Left{} = True; isLeft _ = False
-
--- | Test if an 'Either' value is the 'Right' constructor.
---   Provided as standard with GHC 7.8 and above.
-isRight :: Either l r -> Bool
-isRight Right{} = True; isRight _ = False
-#endif
-
 -- | Pull the value out of an 'Either' where both alternatives
 --   have the same type.
 --
@@ -93,3 +85,20 @@ maybeToEither a Nothing = Left a
 -- > \x -> eitherToMaybe (Right x) == Just x
 eitherToMaybe :: Either a b -> Maybe b
 eitherToMaybe = either (const Nothing) Just
+
+
+-- | The 'mapLeft' function takes a function and applies it to an Either value
+-- iff the value takes the form @'Left' _@.
+--
+-- > mapLeft show (Left 1) == Left "1"
+-- > mapLeft show (Right True) == Right True
+mapLeft :: (a -> c) -> Either a b -> Either c b
+mapLeft f = either (Left . f) Right
+
+-- | The 'mapRight' function takes a function and applies it to an Either value
+-- iff the value takes the form @'Right' _@.
+--
+-- > mapRight show (Left 1) == Left 1
+-- > mapRight show (Right True) == Right "True"
+mapRight :: (b -> c) -> Either a b -> Either a c
+mapRight = fmap
