@@ -1,4 +1,5 @@
-{-# LANGUAGE ScopedTypeVariables #-}
+{-# LANGUAGE ScopedTypeVariables, CPP #-}
+{-# OPTIONS_GHC -fno-warn-duplicate-exports #-}
 
 -- | More IO functions. The functions include ones for reading files with specific encodings,
 --   strictly reading files, and writing files with encodings. There are also some simple
@@ -61,6 +62,9 @@ readFileBinary file = do
 
 -- Strict file reading
 
+#if __GLASGOW_HASKELL__ < 811
+-- readFile' and hGetContents' were added in GHC 9.0
+
 -- | A strict version of 'hGetContents'.
 hGetContents' :: Handle -> IO String
 hGetContents' h = do
@@ -76,6 +80,8 @@ hGetContents' h = do
 readFile' :: FilePath -> IO String
 readFile' file = withFile file ReadMode hGetContents'
 
+#endif
+
 -- | A strict version of 'readFileEncoding', see 'readFile'' for details.
 readFileEncoding' :: TextEncoding -> FilePath -> IO String
 readFileEncoding' e file = withFile file ReadMode $ \h -> hSetEncoding h e >> hGetContents' h
